# Bitvavo API (upgraded)

Hi, this is *not* the official API, but this one has:

- typing for *all* functions and classes
- unit tests (I already found three bugs that I fixed, because the original code wasn't tested, at all)
- a changelog, so you can track of the changes that I make
- compatible with Python 3.7 and newer ([3.6 isn't supported as of 2021-12-23](https://endoflife.date/python))

Version `1.*` is guaranteed compatible with the original API.

## Links

- [official docs](https://docs.bitvavo.com/)
- [Github for this lib](https://github.com/Thaumatorium/bitvavo-api-upgraded)
